/*
   Copyright (C) 1999 PolyWog and Javaman for Ghetto.Org
   This file is part of the PCR-1000 API Library.

   The PCR-1000 API Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The PCR-1000 API Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the PCR-1000 API Library; see the file LICENSE.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.
 */

/*
 *  This file defines bandparse.
 *  This code parses an array of strings into an array of unsigned
 *  short ints, which represents relative signal strength for display
 *  on the bandscope. 
 */

#include "bandparse.h"

Bandparse :: Bandparse(unsigned short int samplesin)
{
	preparsed = NULL;
	parsed = NULL;
	setSampleCount(samplesin);
}

void Bandparse :: setSampleCount(unsigned short int samplesin)
{
	if (preparsed != NULL)
		delete preparsed;
	if (parsed != NULL)
		delete parsed;

	samples = samplesin;

	stringcount = samples/16;
	if (stringcount % 2)
		stringcount++;
	else
		if (samples % 16)
			stringcount += 2;

	preparsed = new char[stringcount * 38];
	parsed = new unsigned short int[samples];
}

unsigned short int Bandparse :: getSampleCount(void)
{
	return (samples);
}

void Bandparse :: DataIn(char **datain)
{
	int i, j;

	j = stringcount * 16 - samples - 2;
	strncpy(preparsed, &datain[0][39-j], j);
	for (i = 1; i < stringcount-1; i++)
		strncat(preparsed, &datain[i][5], 32);
	strncat(preparsed, &datain[stringcount-1][5], j);

	for (i = 0; i < samples * 2; i += 2)
		parsed[i/2] =  hex2dec(preparsed[i]) * 16 + hex2dec(preparsed[i+1]);
}

unsigned short int * Bandparse :: DataOut(void)
{
	return (parsed);
}

unsigned short int Bandparse :: hex2dec (char hex)
{
	if (hex >= 48 & hex <= 57)
		hex -= 48;
	if (hex >= 65 & hex <= 71)
		hex -= 55;
	return (hex);
}

Bandparse :: ~Bandparse ()
{
/*	delete preparsed;	
	delete parsed;*/

	parsed = NULL;
	preparsed = NULL;
}

